@@ -180,7 +180,7 @@ def mass_variance(M, power, lnk, mean_dens):
     rest = np.exp(power + 3 * lnk)
     for i, m in enumerate(M):
         integ = rest * top_hat_window(m, lnk, mean_dens)
-        sigma[i] = (0.5 / np.pi ** 2) * intg.simps(integ, dx=dlnk, even='first')
+        sigma[i] = (0.5 / np.pi ** 2) * intg.trapz(integ, dx=dlnk)
 
     return np.sqrt(sigma)
 
@@ -236,7 +236,7 @@ def dlnsdlnm(M, sigma, power, lnk, mean_dens):
         g = np.exp(lnk) * r
         w = dw2dm(g)  # Derivative of W^2
         integ = w * np.exp(power - lnk)
-        dlnsdlnM[i] = (3.0 / (2.0 * sigma[i] ** 2 * np.pi ** 2 * r ** 4)) * intg.romb(integ, dx=dlnk)
+        dlnsdlnM[i] = (3.0 / (2.0 * sigma[i] ** 2 * np.pi ** 2 * r ** 4)) * intg.trapz(integ, dx=dlnk)
     return dlnsdlnM
 
 def dw2dm(kR):
@@ -267,42 +267,8 @@ def new_k_grid(k, k_bounds=None):
     max_k = np.log(k_bounds[1])
 
     # Setup the grid and fetch the grid-spacing as well
-    k, dlnk = np.linspace(min_k, max_k, 4097, retstep=True)
+    k, dlnk = np.linspace(min_k, max_k, 250, retstep=True)
 
     return k, dlnk
 
-def power_to_corr(lnP, lnk, R):
-    """
-    Calculates the correlation function given a power spectrum
-    
-    NOTE: no check is done to make sure k spans [0,Infinity] - make sure of this before you enter the arguments.
-    
-    INPUT
-        lnP: vector of values for the log power spectrum
-        lnk: vector of values (same length as lnP) giving the log wavenumbers for the power (EQUALLY SPACED)
-        r:   radi(us)(i) at which to calculate the correlation
-    """
-    import matplotlib.pyplot as plt
-    k = np.exp(lnk)
-    P = np.exp(lnP)
-
-    if not isinstance(R, collections.Iterable):
-        R = [R]
-
-    corr = np.zeros_like(R)
-
-    #We must do better than using just 4097 logarithmic bins for k, since
-    #we are integrating over a fast-oscillating function if r is big.
-    integrand_part = spline(lnk, P * k ** 2, k=1)
-    def integ(r, lnk):
-        return integrand_part(lnk) * np.sin(np.exp(lnk) * r) / r
-
-    for i, r in enumerate(R):
-        plt.plot(np.exp(lnk), integ(r, lnk))
-        plt.xscale('log')
-        plt.savefig("/Users/Steven/Documents/dm_corr_plots/" + str(r) + ".png")
-        plt.clf()
-        corr[i] = (0.5 / np.pi ** 2) * intg.quad(lambda k: integ(r, k), -10, 10, epsabs=0, epsrel=10 ** -2, limit=2000)[0]
-
-    return corr
 
